import { Module } from '@nestjs/common';
import { ConfigModule, ConfigService } from '@nestjs/config';
import { HealthModule } from './modules/health/health.module';
import { AdModule } from './modules/ad/ad.module';
import { AutomapperModule } from '@automapper/nestjs';
import { classes } from '@automapper/classes';
import {
  MessageBrokerModule,
  MessageBrokerModuleOptions,
} from '@mobicoop/message-broker-module';
import {
  ConfigurationModule,
  ConfigurationModuleOptions,
} from '@mobicoop/configuration-module';

@Module({
  imports: [
    ConfigModule.forRoot({ isGlobal: true }),
    AutomapperModule.forRoot({ strategyInitializer: classes() }),
    MessageBrokerModule.forRootAsync(
      {
        imports: [ConfigModule],
        inject: [ConfigService],
        useFactory: async (
          configService: ConfigService,
        ): Promise<MessageBrokerModuleOptions> => ({
          uri: configService.get<string>('MESSAGE_BROKER_URI'),
          exchange: configService.get<string>('MESSAGE_BROKER_EXCHANGE'),
        }),
      },
      false,
    ),
    ConfigurationModule.forRootAsync(
      {
        imports: [ConfigModule],
        inject: [ConfigService],
        useFactory: async (
          configService: ConfigService,
        ): Promise<ConfigurationModuleOptions> => ({
          domain: configService.get<string>('SERVICE_CONFIGURATION_DOMAIN'),
          messageBroker: {
            uri: configService.get<string>('MESSAGE_BROKER_URI'),
            exchange: configService.get<string>('MESSAGE_BROKER_EXCHANGE'),
          },
          redis: {
            host: configService.get<string>('REDIS_HOST'),
            password: configService.get<string>('REDIS_PASSWORD'),
            port: configService.get<number>('REDIS_PORT'),
          },
          setConfigurationBrokerRoutingKeys: [
            'configuration.create',
            'configuration.update',
          ],
          deleteConfigurationRoutingKey: 'configuration.delete',
          propagateConfigurationRoutingKey: 'configuration.propagate',
          setConfigurationBrokerQueue: 'ad-configuration-create-update',
          deleteConfigurationQueue: 'ad-configuration-delete',
          propagateConfigurationQueue: 'ad-configuration-propagate',
        }),
      },
      true,
    ),
    HealthModule,
    AdModule,
  ],
  controllers: [],
  providers: [],
})
export class AppModule {}
