import { Module } from '@nestjs/common';
import { AdController } from './adapters/primaries/ad.controller';
import { DatabaseModule } from '../database/database.module';
import { CqrsModule } from '@nestjs/cqrs';
import { AdProfile } from './mappers/ad.profile';
import { AdsRepository } from './adapters/secondaries/ads.repository';
import { FindAdByUuidUseCase } from './domain/usecases/find-ad-by-uuid.usecase';
import { CreateAdUseCase } from './domain/usecases/create-ad.usecase';
import { DefaultParamsProvider } from './adapters/secondaries/default-params.provider';
import { PARAMS_PROVIDER } from './ad.constants';
import { MESSAGE_BROKER_PUBLISHER, MESSAGE_PUBLISHER } from 'src/app.constants';
import { MessageBrokerPublisher } from '@mobicoop/message-broker-module';
import { MessagePublisher } from './adapters/secondaries/message-publisher';

@Module({
  imports: [DatabaseModule, CqrsModule],
  controllers: [AdController],
  providers: [
    AdProfile,
    AdsRepository,
    FindAdByUuidUseCase,
    CreateAdUseCase,
    {
      provide: PARAMS_PROVIDER,
      useClass: DefaultParamsProvider,
    },
    {
      provide: MESSAGE_BROKER_PUBLISHER,
      useClass: MessageBrokerPublisher,
    },
    {
      provide: MESSAGE_PUBLISHER,
      useClass: MessagePublisher,
    },
  ],
})
export class AdModule {}
